/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef nsPluginsCID_h_
#define nsPluginsCID_h_

#define NS_PLUGIN_HOST_CID \
{ 0x23E8FD98, 0xA625, 0x4B08, \
{ 0xBE, 0x1A, 0xF7, 0xCC, 0x18, 0xA5, 0xB1, 0x06 } }

#endif // nsPluginsCID_h_
