/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_ConstraintsBinding_h
#define mozilla_dom_ConstraintsBinding_h

#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/Nullable.h"

namespace mozilla {
namespace dom {

struct ConstrainDoubleRangeAtoms;
struct ConstrainLongRangeAtoms;
class NativePropertyHooks;
class ProtoAndIfaceCache;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {

MOZ_BEGIN_ENUM_CLASS(VideoFacingModeEnum, uint32_t)
  User,
  Environment,
  Left,
  Right,
  EndGuard_
MOZ_END_ENUM_CLASS(VideoFacingModeEnum)

namespace VideoFacingModeEnumValues {
extern const EnumEntry strings[5];
} // namespace VideoFacingModeEnumValues


struct ConstrainDoubleRange : public DictionaryBase
{
  double mMax;
  double mMin;

  ConstrainDoubleRange();

  explicit inline ConstrainDoubleRange(const ConstrainDoubleRange& aOther)
  {
    *this = aOther;
  }

protected:
  explicit inline ConstrainDoubleRange(int )
  {
    // Do nothing here; this is used by our "Fast" subclass
  }

private:
  static bool
  InitIds(JSContext* cx, ConstrainDoubleRangeAtoms* atomsCache);

public:
  bool
  Init(JSContext* cx, JS::Handle<JS::Value> val, const char* sourceDescription = "Value");

  bool
  Init(const nsAString& aJSON);

  bool
  ToObject(JSContext* cx, JS::MutableHandle<JS::Value> rval) const;

  void
  TraceDictionary(JSTracer* trc);

  void
  operator=(const ConstrainDoubleRange& aOther);
};

namespace binding_detail {
struct FastConstrainDoubleRange : public ConstrainDoubleRange
{
  inline FastConstrainDoubleRange()
    : ConstrainDoubleRange(42)
  {
    // Doesn't matter what int we pass to the parent constructor
  }
};
} // namespace binding_detail


struct ConstrainLongRange : public DictionaryBase
{
  int32_t mMax;
  int32_t mMin;

  ConstrainLongRange();

  explicit inline ConstrainLongRange(const ConstrainLongRange& aOther)
  {
    *this = aOther;
  }

protected:
  explicit inline ConstrainLongRange(int )
  {
    // Do nothing here; this is used by our "Fast" subclass
  }

private:
  static bool
  InitIds(JSContext* cx, ConstrainLongRangeAtoms* atomsCache);

public:
  bool
  Init(JSContext* cx, JS::Handle<JS::Value> val, const char* sourceDescription = "Value");

  bool
  Init(const nsAString& aJSON);

  bool
  ToObject(JSContext* cx, JS::MutableHandle<JS::Value> rval) const;

  void
  TraceDictionary(JSTracer* trc);

  void
  operator=(const ConstrainLongRange& aOther);
};

namespace binding_detail {
struct FastConstrainLongRange : public ConstrainLongRange
{
  inline FastConstrainLongRange()
    : ConstrainLongRange(42)
  {
    // Doesn't matter what int we pass to the parent constructor
  }
};
} // namespace binding_detail


} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_ConstraintsBinding_h
