/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMFile;

[uuid(283aa7b2-da81-4c72-aea2-9797b440fe34)]
interface nsIDOMFileList : nsISupports
{
  readonly attribute unsigned long length;
  nsIDOMFile item(in unsigned long index);
};
