/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, function, uuid(9f3ed2c0-aed9-11e1-8c3d-5310bd393466)]
interface nsIAlarmFiredCb : nsISupports 
{
  void onAlarmFired();
};

[scriptable, function, uuid(0ca52e84-ba8f-11e1-87e8-63235527db9e)]
interface nsITimezoneChangedCb : nsISupports 
{
  void onTimezoneChanged(in int32_t aTimezoneOffset);
};

%{C++
#define NS_ALARMHALSERVICE_CID { 0x7dafea4c, 0x7163, 0x4b70, { 0x95, 0x4e, 0x5a, 0xd4, 0x09, 0x94, 0x83, 0xd7 } }
#define ALARMHALSERVICE_CONTRACTID "@mozilla.org/alarmHalService;1"
%}

[scriptable, uuid(057b1ee4-f696-486d-bd55-205e21e88fab)]
interface nsIAlarmHalService : nsISupports
{
  bool setAlarm(in int32_t aSeconds, in int32_t aNanoseconds);
  void setAlarmFiredCb(in nsIAlarmFiredCb aAlarmFiredCb);
  void setTimezoneChangedCb(in nsITimezoneChangedCb aTimezoneChangedCb);
};



